@@ -3,7 +3,7 @@ package Assert::Refute;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 =head1 NAME
 
@@ -123,7 +123,7 @@ would also export the following assertions:
 
 C<is>, C<isnt>, C<ok>, C<use_ok>, C<require_ok>, C<cmp_ok>,
 C<like>, C<unlike>, C<can_ok>, C<isa_ok>, C<new_ok>,
-C<is_deeply>, C<note>, C<diag>.
+C<is_deeply>, C<fail>, C<pass>, C<note>, C<diag>.
 
 See L<Assert::Refute::T::Basic> for more.
 
@@ -719,6 +719,8 @@ for C<try_refute> function name as well as a lot of feedback.
 by C<Daniel Dragan> inspired me to actually start working
 on the first incarnation of this project.
 
+=item * Thanks to C<Jacobo Chamorro> for pass() and fail() calls.
+
 =back
 
 =head1 LICENSE AND COPYRIGHT
