@@ -3,7 +3,7 @@ package Assert::Refute::Report;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 =head1 NAME
 
@@ -285,7 +285,7 @@ The list is as follows:
 
 C<is>, C<isnt>, C<ok>, C<use_ok>, C<require_ok>, C<cmp_ok>,
 C<like>, C<unlike>, C<can_ok>, C<isa_ok>, C<new_ok>,
-C<contract_is>, C<is_deeply>, C<note>, C<diag>.
+C<contract_is>, C<is_deeply>, C<fail>, C<pass>, C<note>, C<diag>.
 
 See L<Assert::Refute::T::Basic> for more details.
 
